define((function () { 'use strict';

  function fn () {
    console.log('main fn');
  }

  return fn;

}));
